@@ -115,6 +115,9 @@ JQ_PASSWORD = '12345678'
 # TuShare账号
 TUSHARE_TOKEN = '12345678'
 
+# eikon账号
+EIKON_APP_KEY = '12345678'
+
 # 米筐账号
 RQ_USERNAME = '13912345678'
 RQ_PASSWORD = '12345678'
